// __multiversion__
// This signals the loading code to prepend either #version 100 or #version 300 es as apropriate.

//pgrv

#ifdef GL_FRAGMENT_PRECISION_HIGH
#define Hme highp
#else
#define Hme mediump
#endif

#include "fragmentVersionCentroid.h"

#if __VERSION__ >= 300

#if defined(TEXEL_AA) && defined(TEXEL_AA_FEATURE)
_centroid in highp vec2 uv;
#else
_centroid in vec2 uv;
#endif

#else

varying vec2 uv;
varying vec4 vs;
varying vec3 ps;

#endif

#include "uniformShaderConstants.h"
#include "util.h"

LAYOUT_BINDING(0) uniform sampler2D TEXTURE_0;
LAYOUT_BINDING(1) uniform sampler2D TEXTURE_1;

#include "g_noise.h"

varying highp vec3 wp;

uniform vec4 FOG_COLOR;
uniform vec2 FOG_CONTROL;
uniform float RENDER_DISTANCE;
uniform Hme float TOTAL_REAL_WORLD_TIME;

highp float sun(highp vec3 uv,highp float blur,highp float sl){
highp float light = length(uv);
highp float cc = smoothstep(sl,sl-blur,light);
return cc;
}

bool rain_factor(){
if(FOG_CONTROL.x > 0.1 && FOG_CONTROL.x < 0.55){
return true;
}else{
return false;
}}

bool dusk_factor(){
if(FOG_COLOR.r*1.0>FOG_COLOR.b){
return true;
}else{
return false;
}}

bool night_factor(){
if(FOG_COLOR.r<0.15 && FOG_COLOR.g<0.15){
return true;
}else{
return false;
}}

void main()
{
#if !defined(TEXEL_AA) || !defined(TEXEL_AA_FEATURE)
	vec4 powervr = texture2D( TEXTURE_0, uv );
#else
	vec4 powervr = texture2D_AA(TEXTURE_0, uv );
#endif

#ifdef ALPHA_TEST
	if(powervr.a < 0.5)
		discard;
#endif

float wtime = texture2D(TEXTURE_1, vec2(0,1)).r;
float wet_ =smoothstep(0.5,0.1,FOG_CONTROL.x);
float dayf = smoothstep(0.15,0.2,FOG_COLOR.g);
float dusk=min(smoothstep(.33,.5,wtime),smoothstep(1.,0.6,wtime))*(1.-wet_)*float(!(night_factor()));
float nights=smoothstep(1.,0.2,wtime);
float day=(1.-wet_)*(1.-dusk)*(1.-nights);
float day2=(1.-wet_);
vec3 p=wp;
float sunposition=mix(mix(0.12,0.,dusk),0.,nights);
p.x+=0.12;
vec3 np=normalize(p);

highp float n = sun(p.xyz,0.01,0.016);
highp float n2 = sun(p.xyz,0.01,0.02);
highp float m2 = sun(p.xyz,0.35,0.03);
highp float m3 = sun(p.xyz,1.,0.25);
highp float m4 = sun(p.xyz,1.,0.2);
highp float m4_2 = sun(p.xyz,0.65,0.1);
highp float m5 = sun(p.xyz,0.75,0.245);
highp float m5_2 = sun(p.xyz,0.3,0.14);
highp float s_f = sun(vec3(p.x*0.8,p.y,p.z),0.35,0.15);

float flare=gcl(vec2(np.x*12.,np.z*24.),5);
powervr.rgb*=vec3(0);

powervr.rgb+=m3*wet_;

powervr.rgb+=n2*dusk;
//powervr.rgb+=m5*dusk;

powervr.rgb+=n2*nights;

powervr.rgb+=n*day;
if(n>=0.){
powervr.rgb+=m4*vec3(1.05)*nights;
powervr.rgb+=m4_2*vec3(1.4,1.2,0.1)*dusk;
//powervr.rgb+=m2*vec3(1,0.9,0.3)*dayf;
powervr.rgb+=m5_2*vec3(1,0.9,0.7)*dayf;
//powervr=mix(powervr,vec4(1),flare);
}

	gl_FragColor = powervr*CURRENT_COLOR;
}
