// __multiversion__
// This signals the loading code to prepend either #version 100 or #version 300 es as apropriate.
//pgrv 
//made by @GLshading

#include "vertexVersionCentroid.h"
#if __VERSION__ >= 300
	#ifndef BYPASS_PIXEL_SHADER
		_centroid out vec2 uv0;
		_centroid out vec2 uv1;
	#endif
#else
	#ifndef BYPASS_PIXEL_SHADER
		varying vec2 uv0;
		varying vec2 uv1;
	#endif
#endif

#ifndef BYPASS_PIXEL_SHADER
	varying vec4 color;
#endif

#ifdef FOG
	varying vec4 fogColor;
#endif

varying highp vec3 p;
varying highp vec3 wp;
varying highp vec2 pw;
varying highp vec3 cp;
varying float water_f;

#include "uniformWorldConstants.h"
#include "uniformPerFrameConstants.h"
#include "uniformShaderConstants.h"
#include "uniformRenderChunkConstants.h"

uniform highp float TOTAL_REAL_WORLD_TIME;
#include "g_setting.h"

attribute POS4 POSITION;
attribute vec4 COLOR;
attribute vec2 TEXCOORD_0;
attribute vec2 TEXCOORD_1;

const float rA = 1.0;
const float rB = 1.0;
const vec3 UNIT_Y = vec3(0,1,0);
const float DIST_DESATURATION = 56.0 / 255.0; //WARNING this value is also hardcoded in the water color, don'tchange //255

highp float hash11(highp float p)
{
	p = fract(p * .1031);
	p *= p + 33.33;
	p *= p + p;
	return fract(p);
}
highp float rand(highp vec3 p){
	highp float x = (p.x+p.y+p.z)/3.0+TOTAL_REAL_WORLD_TIME*1.2;
	return mix(hash11(floor(x)),hash11(ceil(x)),smoothstep(0.0,1.0,fract(x)));
}

bool nether_factor(){
if(FOG_COLOR.r>FOG_COLOR.b && 
FOG_COLOR.r<0.5 && FOG_COLOR.b<0.2){
return true;
}else{
return false;
}}

void main()
{

water_f=0.0;
    POS4 worldPos;
#ifdef AS_ENTITY_RENDERER
		POS4 pos = WORLDVIEWPROJ * POSITION;
		worldPos = pos;
#else
    worldPos.xyz = (POSITION.xyz * CHUNK_ORIGIN_AND_SCALE.w) + CHUNK_ORIGIN_AND_SCALE.xyz;
    worldPos.w = 1.0;

    // Transform to view space before projection instead of all at once to avoid floating point errors
    // Not required for entities because they are already offset by camera translation before rendering
    // World position here is calculated above and can get huge
    POS4 pos = WORLDVIEW * worldPos;
    pos = PROJ * pos;
#endif

    gl_Position = pos;
    p = POSITION.xyz;
    wp = worldPos.xyz;
	pw = pos.xy/(pos.z+1.0);
	cp.xy = pos.xy/(pos.z+1.0);
	cp.z = min(1.,pos.z);

#ifndef BYPASS_PIXEL_SHADER
    uv0 = TEXCOORD_0;
    uv1 = TEXCOORD_1;
	color = COLOR;
#endif

///// find distance from the camera

#if defined(FOG) || defined(BLEND)
	#ifdef FANCY
		vec3 relPos = -worldPos.xyz;
		float cameraDepth = length(relPos);
	#else
		float cameraDepth = pos.y;
	#endif
#endif

///// apply fog

#ifdef FOG
	float len = cameraDepth / RENDER_DISTANCE;
	#ifdef ALLOW_FADE
		len += RENDER_CHUNK_FOG_ALPHA;
	#endif

    fogColor.rgb = FOG_COLOR.rgb;
	fogColor.a = clamp((len - FOG_CONTROL.x) / (FOG_CONTROL.y - FOG_CONTROL.x), 0.0, 1.0);
#endif

highp float t=TOTAL_REAL_WORLD_TIME;
highp vec3 mp=mod(p.xyz,16.);

#if PLANT_WAVES == 1
#if defined(ALPHA_TEST)
if(color.g>color.r){
if(FOG_CONTROL.x > 0.1 && FOG_CONTROL.x < 0.55){
gl_Position.x += (sin(t*1.5+mp.x+mp.z+mp.y)*rand(mp)*0.04)*uv1.y;
}else{ 
gl_Position.x += (sin(t*1.+mp.x+mp.z+mp.y)*rand(mp)*0.03)*uv1.y;}}
#endif
#endif

#if UNDERWATER_WAVES == 1
gl_Position.x +=(sin(t*3.8+mp.x+mp.y+mp.x)*sin(mp.z)*0.05)*smoothstep(.13,.12,FOG_CONTROL.x)*ax(step(FOG_COLOR.r,0.),step(FOG_COLOR.g,0.))*((1.-step(0.1,FOG_CONTROL.x/FOG_CONTROL.y)-step(0.12,FOG_CONTROL.x/FOG_CONTROL.y)));
#endif

///// blended layer (mostly water) magic
#if defined(BLEND) && !defined (ALPHA_TEST)
	//Mega hack: only things that become opaque are allowed to have vertex-driven transparency in the Blended layer...
	//to fix this we'd need to find more space for a flag in the vertex format. color.a is the only unused part
	bool shouldBecomeOpaqueInTheDistance = color.a < 0.95;
	if(shouldBecomeOpaqueInTheDistance) {
		#ifdef FANCY  /////enhance water
			float cameraDist = cameraDepth / FAR_CHUNKS_DISTANCE;
			color = COLOR;
		#else
			// Completely insane, but if I don't have these two lines in here, the water doesn't render on a Nexus 6
			vec4 surfColor = vec4(color.rgb, 1.0);
			color = surfColor;
				
			vec3 relPos = -worldPos.xyz;
			float camDist = length(relPos);
			float cameraDist = camDist / FAR_CHUNKS_DISTANCE;
		#endif //FANCY
		
		water_f=1.0;
		
		
		float alphaFadeOut = clamp(cameraDist, 0.0, 1.0);
		color.a = mix(color.a, 1.0, alphaFadeOut);
	}
#endif
 
//made by @GLshading

#ifndef BYPASS_PIXEL_SHADER
	#ifndef FOG
		// If the FOG_COLOR isn't used, the reflection on NVN fails to compute the correct size of the constant buffer as the uniform will also be gone from the reflection data
		color.rgb += FOG_COLOR.rgb * 0.000001;
	#endif
#endif
}
